@@ -18,6 +18,7 @@ class KeywordsList:
     def __init__(self, sentence, params):
         self.keywords = []
 
+        self.treetagger=params.treetagger
         self.postag=params.postag
         self.lang = params.lang
         self.noun=params.noun
@@ -49,7 +50,7 @@ class KeywordsList:
             return self.keywords[num][0]
         else:
             return self.keywords[num]
-            
+
     def getScore(self, num):
         if self.postag:
             return self.keywords[num][1]
@@ -106,7 +107,7 @@ class KeywordsList:
     def getPostagScore(self,w):
         shell = 1
         if shell:
-            proc = subprocess.Popen(["echo '"+w+"' | tree-tagger -lemma -quiet ~/Documents/TreeTagger/lib/french-utf8.par |cut -d ' ' -f 1", ""], stdout=subprocess.PIPE, shell=True)
+            proc = subprocess.Popen(["echo '"+w+"' | tree-tagger -lemma -quiet "+self.treetagger+"/lib/french-utf8.par |cut -d ' ' -f 1", ""], stdout=subprocess.PIPE, shell=True)
             (out, err) = proc.communicate()
             #print "Category:", out
             # Depending on category, score
